#By Roberto Moreno Bonnín - 2023


#!/bin/bash

UNI=""
UNI_PORT=0
#Contiene una herramienta (Cryptogen) para crear certificados de prueba encriptar y desencriptar el bloque genesis etc…
export PATH=${PWD}/bin:${PWD}:$PATH
# este export… verificar que todo funciona incluyendo docker-compose
export PATH=${PWD}/bin:${PWD}:/usr/local/bin:bin:$PATH
#Configuración que utilizarán los Nodos orderer y la ca
export FABRIC_CFG_PATH=${PWD}/config

ORDERERHOST="orderer.universidades.com"
CHANNEL="universidadeschannel"
CHAINCODE="univesidades"
#Para controlar las versiones en el peer
CHAINCODESEQUENCE="1" 
CHAINCODEVER="1.0"


function install() {
  echo "Download and installing Hyperledger fabric binaries"
  CUR_DIR=${PWD}
  cd ~
  curl -sSL https://bit.ly/2ysbOFE | sudo bash -s -- 2.4.4 1.5.3
  cd fabric-samples
  cp -r ./bin ${CUR_DIR}
  cd ${CUR_DIR}
}

function clearHyper() {
  echo "Cleaning previos config CA's & containers"
  docker stop $(docker ps -a -q) 
  docker rm $(docker ps -a -q) 
  docker volume prune 
  docker network prune 

  docker rmi $(docker images --format "{{.ID}} {{.Repository}}:{{.Tag}}" | grep -E 'universidades' | awk '{print $1}')

  sudo rm -rf organizations/peerOrganizations 
  sudo rm -rf organizations/ordererOrganizations

  sudo rm -rf organizations/fabric-ca/uoc
  sudo rm -rf organizations/fabric-ca/uib
  sudo rm -rf organizations/fabric-ca/uab
  sudo rm -rf organizations/fabric-ca/orderer 


  sudo rm -rf channel-artifacts/ 
  mkdir channel-artifacts

  sudo rm -rf ../rest/wallet
  mkdir ../rest/wallet
  echo "Cleaning process has finished"
}

function createOrderer() {
  echo "Enrolling the CA admin"
  mkdir -p organizations/ordererOrganizations/universidades.com

  export FABRIC_CA_CLIENT_HOME=${PWD}/organizations/ordererOrganizations/universidades.com

  set -x
  fabric-ca-client enroll -u https://admin:adminpw@localhost:9054 --caname ca-orderer --tls.certfiles "${PWD}/organizations/fabric-ca/orderer/tls-cert.pem"
  { set +x; } 2>/dev/null

  echo 'NodeOUs:
  Enable: true
  ClientOUIdentifier:
    Certificate: cacerts/localhost-9054-ca-orderer.pem
    OrganizationalUnitIdentifier: client
  PeerOUIdentifier:
    Certificate: cacerts/localhost-9054-ca-orderer.pem
    OrganizationalUnitIdentifier: peer
  AdminOUIdentifier:
    Certificate: cacerts/localhost-9054-ca-orderer.pem
    OrganizationalUnitIdentifier: admin
  OrdererOUIdentifier:
    Certificate: cacerts/localhost-9054-ca-orderer.pem
    OrganizationalUnitIdentifier: orderer' > "${PWD}/organizations/ordererOrganizations/universidades.com/msp/config.yaml"

  echo "Registering orderer"
  set -x
  fabric-ca-client register --caname ca-orderer --id.name orderer --id.secret ordererpw --id.type orderer --tls.certfiles "${PWD}/organizations/fabric-ca/orderer/tls-cert.pem"
  { set +x; } 2>/dev/null

  echo "Registering the orderer admin"
  set -x
  fabric-ca-client register --caname ca-orderer --id.name ordererAdmin --id.secret ordererAdminpw --id.type admin --tls.certfiles "${PWD}/organizations/fabric-ca/orderer/tls-cert.pem"
  { set +x; } 2>/dev/null

  echo "Generating the orderer msp"
  set -x
  fabric-ca-client enroll -u https://orderer:ordererpw@localhost:9054 --caname ca-orderer -M "${PWD}/organizations/ordererOrganizations/universidades.com/orderers/orderer.universidades.com/msp" --csr.hosts orderer.universidades.com --csr.hosts localhost --tls.certfiles "${PWD}/organizations/fabric-ca/orderer/tls-cert.pem"
  { set +x; } 2>/dev/null

  cp "${PWD}/organizations/ordererOrganizations/universidades.com/msp/config.yaml" "${PWD}/organizations/ordererOrganizations/universidades.com/orderers/orderer.universidades.com/msp/config.yaml"

  echo "Generating the orderer-tls certificates"
  set -x
  fabric-ca-client enroll -u https://orderer:ordererpw@localhost:9054 --caname ca-orderer -M "${PWD}/organizations/ordererOrganizations/universidades.com/orderers/orderer.universidades.com/tls" --enrollment.profile tls --csr.hosts orderer.universidades.com --csr.hosts localhost --tls.certfiles "${PWD}/organizations/fabric-ca/orderer/tls-cert.pem"
  { set +x; } 2>/dev/null

  cp "${PWD}/organizations/ordererOrganizations/universidades.com/orderers/orderer.universidades.com/tls/tlscacerts/"* "${PWD}/organizations/ordererOrganizations/universidades.com/orderers/orderer.universidades.com/tls/ca.crt"
  cp "${PWD}/organizations/ordererOrganizations/universidades.com/orderers/orderer.universidades.com/tls/signcerts/"* "${PWD}/organizations/ordererOrganizations/universidades.com/orderers/orderer.universidades.com/tls/server.crt"
  cp "${PWD}/organizations/ordererOrganizations/universidades.com/orderers/orderer.universidades.com/tls/keystore/"* "${PWD}/organizations/ordererOrganizations/universidades.com/orderers/orderer.universidades.com/tls/server.key"

  mkdir -p "${PWD}/organizations/ordererOrganizations/universidades.com/orderers/orderer.universidades.com/msp/tlscacerts"
  cp "${PWD}/organizations/ordererOrganizations/universidades.com/orderers/orderer.universidades.com/tls/tlscacerts/"* "${PWD}/organizations/ordererOrganizations/universidades.com/orderers/orderer.universidades.com/msp/tlscacerts/tlsca.universidades.com-cert.pem"

  mkdir -p "${PWD}/organizations/ordererOrganizations/universidades.com/msp/tlscacerts"
  cp "${PWD}/organizations/ordererOrganizations/universidades.com/orderers/orderer.universidades.com/tls/tlscacerts/"* "${PWD}/organizations/ordererOrganizations/universidades.com/msp/tlscacerts/tlsca.universidades.com-cert.pem"

  echo "Generating the admin msp"
  set -x
  fabric-ca-client enroll -u https://ordererAdmin:ordererAdminpw@localhost:9054 --caname ca-orderer -M "${PWD}/organizations/ordererOrganizations/universidades.com/users/Admin@universidades.com/msp" --tls.certfiles "${PWD}/organizations/fabric-ca/orderer/tls-cert.pem"
  { set +x; } 2>/dev/null

  cp "${PWD}/organizations/ordererOrganizations/universidades.com/msp/config.yaml" "${PWD}/organizations/ordererOrganizations/universidades.com/users/Admin@universidades.com/msp/config.yaml"
}

function createUniCert() {
  export CURRENT_PATH=${PWD}/organizations
  export TLS_CERTSPATH="${CURRENT_PATH}/fabric-ca/${UNI}/tls-cert.pem"
  echo "Enrolling the CA admin"

  mkdir -p ${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/
           
  export FABRIC_CA_CLIENT_HOME=${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/
  echo "ruta"
  echo $FABRIC_CA_CLIENT_HOME

  set -x
  fabric-ca-client enroll -u https://admin:adminpw@localhost:${UNICA_PORT} --caname ca-${UNI} --tls.certfiles ${TLS_CERTSPATH}
  { set +x; } 2>/dev/null

  echo 'NodeOUs:
  Enable: true
  ClientOUIdentifier:
    Certificate: cacerts/localhost-${UNICA_PORT}-ca-${UNI}.pem
    OrganizationalUnitIdentifier: client
  PeerOUIdentifier:
    Certificate: cacerts/localhost-${UNICA_PORT}-ca-${UNI}.pem
    OrganizationalUnitIdentifier: peer
  AdminOUIdentifier:
    Certificate: cacerts/localhost-${UNICA_PORT}-ca-${UNI}.pem
    OrganizationalUnitIdentifier: admin
  OrdererOUIdentifier:
    Certificate: cacerts/localhost-${UNICA_PORT}-ca-${UNI}.pem
    OrganizationalUnitIdentifier: orderer' 
  echo "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/msp/config.yaml"

  cat > "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/msp/config.yaml" << EOF
      NodeOUs:
        Enable: true
        ClientOUIdentifier:
          Certificate: cacerts/localhost-${UNICA_PORT}-ca-${UNI}.pem
          OrganizationalUnitIdentifier: client
        PeerOUIdentifier:
          Certificate: cacerts/localhost-${UNICA_PORT}-ca-${UNI}.pem
          OrganizationalUnitIdentifier: peer
        AdminOUIdentifier:
          Certificate: cacerts/localhost-${UNICA_PORT}-ca-${UNI}.pem
          OrganizationalUnitIdentifier: admin
        OrdererOUIdentifier:
          Certificate: cacerts/localhost-${UNICA_PORT}-ca-${UNI}.pem
          OrganizationalUnitIdentifier: orderer
EOF

  echo "Registering peer0"
  set -x
  fabric-ca-client register --caname ca-${UNI} --id.name peer0 --id.secret peer0pw --id.type peer --tls.certfiles ${TLS_CERTSPATH}
  { set +x; } 2>/dev/null

  echo "Registering user"
  set -x
  fabric-ca-client register --caname ca-${UNI} --id.name user1 --id.secret user1pw --id.type client --tls.certfiles ${TLS_CERTSPATH}
  { set +x; } 2>/dev/null

  echo "Registering the org admin"
  set -x
  fabric-ca-client register --caname ca-${UNI} --id.name ${UNI}admin --id.secret ${UNI}adminpw --id.type admin --tls.certfiles ${TLS_CERTSPATH}
  { set +x; } 2>/dev/null

  echo "Generating the peer0 msp"
  set -x
  fabric-ca-client enroll -u https://peer0:peer0pw@localhost:${UNICA_PORT} --caname ca-${UNI} -M "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/peers/peer0.${UNI}.universidades.com/msp" --csr.hosts peer0.${UNI}.universidades.com --tls.certfiles ${TLS_CERTSPATH}
  { set +x; } 2>/dev/null

  cp "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/msp/config.yaml" "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/peers/peer0.${UNI}.universidades.com/msp/config.yaml"

  echo "Generating the peer0-tls certificates"
  set -x
  fabric-ca-client enroll -u https://peer0:peer0pw@localhost:${UNICA_PORT} --caname ca-${UNI} -M "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/peers/peer0.${UNI}.universidades.com/tls" --enrollment.profile tls --csr.hosts peer0.${UNI}.universidades.com --csr.hosts localhost --tls.certfiles ${TLS_CERTSPATH}
  { set +x; } 2>/dev/null

  cp "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/peers/peer0.${UNI}.universidades.com/tls/tlscacerts/"* "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/peers/peer0.${UNI}.universidades.com/tls/ca.crt"
  cp "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/peers/peer0.${UNI}.universidades.com/tls/signcerts/"* "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/peers/peer0.${UNI}.universidades.com/tls/server.crt"
  cp "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/peers/peer0.${UNI}.universidades.com/tls/keystore/"* "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/peers/peer0.${UNI}.universidades.com/tls/server.key"

  mkdir -p "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/msp/tlscacerts"
  cp "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/peers/peer0.${UNI}.universidades.com/tls/tlscacerts/"* "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/msp/tlscacerts/ca.crt"

  mkdir -p "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/tlsca"
  cp "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/peers/peer0.${UNI}.universidades.com/tls/tlscacerts/"* "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/tlsca/tlsca.${UNI}.universidades.com-cert.pem"

  mkdir -p "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/ca"
  cp "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/peers/peer0.${UNI}.universidades.com/msp/cacerts/"* "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/ca/ca.${UNI}.universidades.com-cert.pem"

  echo "Generating the user msp"
  set -x
  fabric-ca-client enroll -u https://user1:user1pw@localhost:${UNICA_PORT} --caname ca-${UNI} -M "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/users/User1@${UNI}.universidades.com/msp" --tls.certfiles  ${TLS_CERTSPATH}
  { set +x; } 2>/dev/null

  cp "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/msp/config.yaml" "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/users/User1@${UNI}.universidades.com/msp/config.yaml"

  echo "Generating the org admin msp"
  set -x
  fabric-ca-client enroll -u https://${UNI}admin:${UNI}adminpw@localhost:${UNICA_PORT} --caname ca-${UNI} -M "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/users/Admin@${UNI}.universidades.com/msp" --tls.certfiles  ${TLS_CERTSPATH}
  { set +x; } 2>/dev/null

  cp "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/msp/config.yaml" "${CURRENT_PATH}/peerOrganizations/${UNI}.universidades.com/users/Admin@${UNI}.universidades.com/msp/config.yaml"
}
function createCerts()
{

    echo "Creating certificates" 
    docker-compose -f docker/docker-compose-ca.yaml up -d    
    echo "Esperando...."
    sleep 5 
    export UNI="uoc"
    export UNICA_PORT=7054  
    createUniCert
    
    export UNI="uib"
    export UNICA_PORT=8054 
    createUniCert
    export UNI="uab"
    export UNICA_PORT=9154 
    createUniCert
    UNI="orderer"
    UNICA_PORT=9054
    createOrderer

    docker-compose -f docker/docker-compose-universidades.yaml up -d
    echo "Esperando..."
    sleep 2
    export FABRIC_CFG_PATH=${PWD}/config
    configtxgen -profile UniversidadesGenesis -outputBlock ./channel-artifacts/${CHANNEL}.block -channelID ${CHANNEL}
    echo "Creating process has finished"

}
function createCertsCryptogen()
{

    echo "Creating certificates" 
       
    cryptogen generate --config=./organizations/cryptogen/crypto-config-uoc.yaml --output="organizations"
    cryptogen generate --config=./organizations/cryptogen/crypto-config-uib.yaml --output="organizations"
    cryptogen generate --config=./organizations/cryptogen/crypto-config-uab.yaml --output="organizations"
    cryptogen generate --config=./organizations/cryptogen/crypto-config-orderer.yaml --output=organizations
    docker-compose -f docker/docker-compose-universidades.yaml up -d

    export FABRIC_CFG_PATH=${PWD}/config
    configtxgen -profile UniversidadesGenesis -outputBlock ./channel-artifacts/${CHANNEL}.block -channelID ${CHANNEL}
    echo "Creating process has finished"

}
function setOrderer()
{
  #export ORDERER_CA=${PWD}/organizations/ordererOrganizations/universidades.com/orderers/${ORDERERHOST}/msp/tlscacerts/tlsca.universidades.com-cert.pem
  #export ORDERER_ADMIN_TLS_SIGN_CERT=${PWD}/organizations/ordererOrganizations/universidades.com/orderers/${ORDERERHOST}/tls/server.crt
  #export ORDERER_ADMIN_TLS_PRIVATE_KEY=${PWD}/organizations/ordererOrganizations/universidades.com/orderers/${ORDERERHOST}/tls/server.key
  export ORDERER_CA=${PWD}/organizations/ordererOrganizations/universidades.com/orderers/${ORDERERHOST}/msp/tlscacerts/tlsca.universidades.com-cert.pem
  export ORDERER_ADMIN_TLS_SIGN_CERT=${PWD}/organizations/ordererOrganizations/universidades.com/orderers/${ORDERERHOST}/tls/server.crt
  export ORDERER_ADMIN_TLS_PRIVATE_KEY=${PWD}/organizations/ordererOrganizations/universidades.com/orderers/${ORDERERHOST}/tls/server.key


  sleep 2 
}
function setUni()
{
  export CORE_PEER_TLS_ENABLED=true
  export PEER_CA=${PWD}/organizations/peerOrganizations/${UNI}.universidades.com/peers/peer0.${UNI}.universidades.com/tls/ca.crt
  export CORE_PEER_LOCALMSPID="${UNI}MSP"
  export CORE_PEER_TLS_ROOTCERT_FILE=${PEER_CA}
  export CORE_PEER_MSPCONFIGPATH=${PWD}/organizations/peerOrganizations/${UNI}.universidades.com/users/Admin@${UNI}.universidades.com/msp
  export CORE_PEER_ADDRESS=localhost:${UNI_PORT}
  sleep 2
}
function setuoc()
{
  UNI="uoc"
  UNI_PORT=7051  
  setUni
  export UOC_CA=${PEER_CA}

}
function setuib()
{
  UNI="uib"
  UNI_PORT=9051
  setUni
  export UIB_CA=${PEER_CA}
}
function setuab()
{
  UNI="uab"
  UNI_PORT=9151
  setUni
  export UAB_CA=${PEER_CA}
}
function createChannel()
{
  setOrderer
  #Se Lanza al orderer el bloque genesis con la configuración de un canal   
  # y sumar los nodos del resto de universidades
  # para esto nos ponemos en el rol del Orderer para poder operar
  
  osnadmin channel join --channelID ${CHANNEL} --config-block ./channel-artifacts/${CHANNEL}.block -o localhost:7053 --ca-file "$ORDERER_CA" --client-cert "$ORDERER_ADMIN_TLS_SIGN_CERT" --client-key "$ORDERER_ADMIN_TLS_PRIVATE_KEY"

  #Verificar la creación del canal en el orderer
  osnadmin channel list -o localhost:7053 --ca-file "$ORDERER_CA" --client-cert "$ORDERER_ADMIN_TLS_SIGN_CERT" --client-key "$ORDERER_ADMIN_TLS_PRIVATE_KEY"  
}
function joinChannel()
{ 
  #setUni
  echo "Uniendo Uni "${UNI}" en el puerto " ${UNI_PORT}
  #Y ahora nos unimos al canal
  peer channel join -b ./channel-artifacts/${CHANNEL}.block 
  #sed -i "s|$old|$new|g" $file
}
function packageChainCode()
{
  cd chaincode
  cd javascript
  echo "Building contract..."
  npm install --save fabric-contract-api
  cd .. 
  cd ..
  echo "packaing contract..."
  sleep 2
  peer lifecycle chaincode package ${CHAINCODE}.tar.gz --path ./chaincode/javascript/ --lang node --label ${CHAINCODE}_${CHAINCODEVER}
  sleep 2  
}
function setPackageId()
{
  #Solo para 1 contrato
  PACKAGEID=$(peer lifecycle chaincode queryinstalled)
  #echo $PACKAGEID
  export PACKAGEID=$(echo ${CHAINCODE}_${CHAINCODEVER}':'$(echo  $(echo $PACKAGEID| cut -d':' -f 4)| cut -d',' -f 1))
  export CC_PACKAGE_ID=${PACKAGEID}
  
  echo "Id paquete instalado"
  echo $PACKAGEID
  echo $CC_PACKAGE_ID
}

function createChain()
{

  createCerts
  createChannel  
  echo "Proceso de creación de canal finalizado"
  echo "uniendo al canal..."
  sleep 2
  setuoc
  joinChannel
  setuib
  joinChannel
  setuab
  joinChannel
  setOrderer
}
function installCC
{
  setuoc
  echo "instalando en uoc"
  peer lifecycle chaincode install ${CHAINCODE}.tar.gz
  sleep 2
  setuib
  echo "instalando en uib"
  peer lifecycle chaincode install ${CHAINCODE}.tar.gz
  sleep 2
  setuab
  echo "instalando en uab"
  peer lifecycle chaincode install ${CHAINCODE}.tar.gz
  sleep 2
}
function approveformyorg
{
   peer lifecycle chaincode approveformyorg -o localhost:7050 --ordererTLSHostnameOverride ${ORDERERHOST} --channelID ${CHANNEL} --name ${CHAINCODE} --version ${CHAINCODEVER} --package-id $CC_PACKAGE_ID --sequence $CHAINCODESEQUENCE --tls --cafile "${ORDERER_CA}" 
}
function commitCC
{
  echo "aprobando en comitando 1"
  peer lifecycle chaincode checkcommitreadiness --channelID ${CHANNEL} --name ${CHAINCODE} --version ${CHAINCODEVER} --sequence $CHAINCODESEQUENCE --tls --cafile "${ORDERER_CA}" --output json

  echo "aprobando en comitando 2"
  peer lifecycle chaincode commit -o localhost:7050 --ordererTLSHostnameOverride ${ORDERERHOST} --channelID ${CHANNEL} --name ${CHAINCODE} --version ${CHAINCODEVER} --sequence $CHAINCODESEQUENCE --tls --cafile "${ORDERER_CA}" --peerAddresses localhost:7051 --tlsRootCertFiles "${UOC_CA}" --peerAddresses localhost:9051 --tlsRootCertFiles "${UIB_CA}" --peerAddresses localhost:9151 --tlsRootCertFiles "${UAB_CA}"

  echo "query committed"
  peer lifecycle chaincode querycommitted --channelID ${CHANNEL} --name ${CHAINCODE} --cafile "${ORDERER_CA}"
}
function aproveCC
{
  echo "aprobando uab"
  setuab
  approveformyorg
  setuib
  echo "aprobando uib"
  approveformyorg
  echo "aprobando uoc"
  setuoc
  approveformyorg

}
function contract()
{
  packageChainCode
  installCC
  setPackageId
  aproveCC
  commitCC
  sleep 2
  echo "Invoke"
  #peer chaincode invoke -o localhost:7050 --ordererTLSHostnameOverride ${ORDERERHOST} --tls --cafile "${ORDERER_CA}" -C ${CHANNEL} -n ${CHAINCODE} --peerAddresses localhost:7051 --tlsRootCertFiles "${UOC_CA}" --peerAddresses localhost:9051 --tlsRootCertFiles "${UIB_CA}" --peerAddresses localhost:9151 --tlsRootCertFiles "${UAB_CA}" -c '{"function":"initLedger","Args":[]}'
  peer chaincode invoke -o localhost:7050 --ordererTLSHostnameOverride ${ORDERERHOST} --tls --cafile "${ORDERER_CA}" -C ${CHANNEL} -n ${CHAINCODE} --peerAddresses localhost:7051 --tlsRootCertFiles "${UOC_CA}" --peerAddresses localhost:9051 --tlsRootCertFiles "${UIB_CA}" --peerAddresses localhost:9151 --tlsRootCertFiles "${UAB_CA}" -c '{"function":"init","Args":[]}'
  
  sleep 2
  #peer chaincode query -C ${CHANNEL} -n ${CHAINCODE} -c '{"Args":["queryAllCars"]}'
  #peer chaincode query -C ${CHANNEL} -n ${CHAINCODE} -c '{"Args":["queryAllCarreras"]}'


  



}
function init()
{
  clearHyper
  createChain
  contract
}

function query()
{
  #Testeo de consultas...
  setOrderer
  setuab
  peer chaincode query -C ${CHANNEL} -n ${CHAINCODE} -c '{"Args":["queryAllCarreras"]}'

  peer chaincode query -C ${CHANNEL} -n ${CHAINCODE} -c '{"Args":["queryAllByType", "Alumno"]}'
  peer chaincode query -C ${CHANNEL} -n ${CHAINCODE} -c '{"Args":["queryAllByType", "MyCareer"]}'

}


